ProjectKind

Enum ProjectKind 

pub enum ProjectKind {
Show 17 variants Rust, Node, Python, Java, DotNet, Go, Zig, CMake, Swift, Elixir, Haskell, Dart, Ruby, Scala, Unity, Godot, Terraform,
}
The kind of development project detected.

Variants



Rust



Node



Python



Java



DotNet



Go



Zig



CMake



Swift



Elixir



Haskell



Dart



Ruby



Scala



Unity



Godot



Terraform

Implementations

Source

impl ProjectKind

pub fn marker_files(&self) -> &[&str]

Returns the marker file(s) used to detect this project kind.

pub fn cleanable_dirs(&self) -> &[&str]

Returns the directories that can be safely cleaned for this project kind.

pub fn all() -> &'static [ProjectKind]

Returns all known project kinds.